import { CloudFrontWebDistribution } from '@aws-cdk/aws-cloudfront';
import { Bucket } from '@aws-cdk/aws-s3';
import { Construct } from '@aws-cdk/core';
export interface SinglePageAppHostingProps {
    /**
     * Name of the domain to deploy
     */
    readonly domainName: string;
    /**
     * Name of the HostedZone of the domain
     *
     * @default - same a the domain name
     */
    readonly zoneName?: string;
    /**
     * Name of the index document
     *
     * @default index.html
     */
    readonly indexFile?: string;
    /**
     * The ARN of the certificate; Has to be in us-east-1
     *
     * @default - create a new certificate in us-east-1
     */
    readonly certArn?: string;
    /**
     * ID of the HostedZone of the domain
     *
     * @default - lookup zone from context using the zone name
     */
    readonly zoneId?: string;
    /**
     * local folder with contents for the website bucket
     *
     * @default - no file deployment
     */
    readonly webFolder?: string;
}
export declare class SinglePageAppHosting extends Construct {
    readonly webBucket: Bucket;
    readonly distribution: CloudFrontWebDistribution;
    constructor(scope: Construct, id: string, props: SinglePageAppHostingProps);
}
